@@ -240,6 +240,8 @@ class Parser:
 class MedlineXMLParser(Parser):
     """A parser for (offline) MEDLINE XML (files)."""
 
+    TRUNC_MSG = re.compile(r'\(ABSTRACT TRUNCATED AT \d+ WORDS\)$')
+
     def __init__(self, *args, **kwargs):
         super(MedlineXMLParser, self).__init__(*args, **kwargs)
         self.seq = 0
@@ -274,7 +276,16 @@ class MedlineXMLParser(Parser):
         name = element.get('NlmCategory', 'Unassigned').capitalize()
         content = element.text.strip()
         label = element.get('Label', None)
-        return Section(self.pmid, source, self.seq, name, content, label)
+        truncated = False
+
+        if MedlineXMLParser.TRUNC_MSG.search(content):
+            content = MedlineXMLParser.TRUNC_MSG.sub('', content).rstrip()
+            truncated = True
+
+            if not content:
+                content = ' '  # truncated the whole section; use a space (placeholder)
+
+        return Section(self.pmid, source, self.seq, name, content, label, truncated)
 
     def AuthorList(self, element):
         for pos, author in enumerate(element.getchildren()):
@@ -321,6 +332,8 @@ class MedlineXMLParser(Parser):
                     pass
                 elif child.tag == 'Affiliation':
                     pass
+                elif child.tag == 'AffiliationInfo':
+                    pass
                 else:
                     logger.warning('unknown Author element %s "%s" in %i',
                                    child.tag, text, self.pmid)
@@ -349,12 +362,13 @@ class MedlineXMLParser(Parser):
         name = element.find('DataBankName')
 
         if name is not None and name.text:
-            done = set()
+            accessions = {acc for acc in map(
+                lambda e: e.text.strip() if e.text else None,
+                element.find('AccessionNumberList').getchildren()
+            ) if acc}
 
-            for acc in element.find('AccessionNumberList').getchildren():
-                if acc.text and acc.text not in done:
-                    done.add(acc.text)
-                    yield Database(self.pmid, name.text, acc.text)
+            for acc in accessions:
+                yield Database(self.pmid, name.text, acc)
 
     def ELocationID(self, element):
         ns = element.get('EIdType').strip().lower()
@@ -371,6 +385,9 @@ class MedlineXMLParser(Parser):
             if keyword.text is not None:
                 text = keyword.text.strip()
 
+                if '\r' in text:
+                    text = text[:text.find('\r')]
+
                 if text:
                     yield Keyword(
                         self.pmid, owner, cnt + 1, text,
